@@ -61,9 +61,9 @@ struct TP_QT_NO_EXPORT ContactManager::Private
     WeakPtr<Connection> connection;
     ContactManager::Roster *roster;
 
-    QHash<uint, WeakPtr<Contact> > contacts;
+    QMap<uint, WeakPtr<Contact> > contacts;
 
-    QHash<Feature, bool> tracking;
+    QMap<Feature, bool> tracking;
     Features supportedFeatures;
 
     // avatar
@@ -252,8 +252,7 @@ Features ContactManager::supportedFeatures() const
             << Contact::FeatureLocation
             << Contact::FeatureInfo
             << Contact::FeatureRosterGroups
-            << Contact::FeatureAddresses
-            << Contact::FeatureClientTypes;
+            << Contact::FeatureAddresses;
         QStringList interfaces = connection()->lowlevel()->contactAttributeInterfaces();
         foreach (const Feature &feature, allFeatures) {
             if (interfaces.contains(featureToInterface(feature))) {
@@ -1085,14 +1084,14 @@ PendingContacts *ContactManager::contactsForIdentifiers(const QStringList &ident
 }
 
 /**
- * Request contacts and enable their \a features using a given field in their vcards.
+ * Request contacts and enable their \a features using a given field in their vCards.
  *
  * This method requires Connection::FeatureCore to be ready.
  *
- * \param vcardField The vcard field of the addresses we are requesting.
+ * \param vcardField The vCard field of the addresses we are requesting.
  *                   Supported fields can be found in ProtocolInfo::addressableVCardFields().
  * \param vcardAddresses The addresses to get contacts for. The address types must match
- *                       the given vcard field.
+ *                       the given vCard field.
  * \param features The Contact features to enable.
  * \return A PendingContacts, which will emit PendingContacts::finished
  *         when the contacts are retrieved or an error occurred.
@@ -1341,27 +1340,17 @@ void ContactManager::onAvatarRetrieved(uint handle, const QString &token,
         debug() << "Filename:" << avatarFileName;
         debug() << "MimeType:" << mimeType;
 
-        if (!QFile::exists(mimeTypeFileName)) {
-            QTemporaryFile mimeTypeFile(mimeTypeFileName);
-            if (mimeTypeFile.open()) {
-                mimeTypeFile.write(mimeType.toLatin1());
-                mimeTypeFile.setAutoRemove(false);
-                if (!mimeTypeFile.rename(mimeTypeFileName)) {
-                    mimeTypeFile.remove();
-                }
-            }
-        }
+        QTemporaryFile mimeTypeFile(mimeTypeFileName);
+        mimeTypeFile.open();
+        mimeTypeFile.write(mimeType.toLatin1());
+        mimeTypeFile.setAutoRemove(false);
+        mimeTypeFile.rename(mimeTypeFileName);
 
-        if (!QFile::exists(avatarFileName)) {
-            QTemporaryFile avatarFile(avatarFileName);
-            if (avatarFile.open()) {
-                avatarFile.write(data);
-                avatarFile.setAutoRemove(false);
-                if (!avatarFile.rename(avatarFileName)) {
-                    avatarFile.remove();
-                }
-            }
-        }
+        QTemporaryFile avatarFile(avatarFileName);
+        avatarFile.open();
+        avatarFile.write(data);
+        avatarFile.setAutoRemove(false);
+        avatarFile.rename(avatarFileName);
     }
 
     ContactPtr contact = lookupContactByHandle(handle);
@@ -1419,17 +1408,6 @@ void ContactManager::onContactInfoChanged(uint handle, const Tp::ContactInfoFiel
     }
 }
 
-void ContactManager::onClientTypesUpdated(uint handle, const QStringList &clientTypes)
-{
-    debug() << "Got ClientTypesUpdated for contact with handle" << handle;
-
-    ContactPtr contact = lookupContactByHandle(handle);
-
-    if (contact) {
-        contact->receiveClientTypes(clientTypes);
-    }
-}
-
 void ContactManager::doRefreshInfo()
 {
     PendingRefreshContactInfo *op = mPriv->refreshInfoOp;
@@ -1493,9 +1471,7 @@ QString ContactManager::featureToInterface(const Feature &feature)
     } else if (feature == Contact::FeatureRosterGroups) {
         return TP_QT_IFACE_CONNECTION_INTERFACE_CONTACT_GROUPS;
     } else if (feature == Contact::FeatureAddresses) {
-        return TP_QT_IFACE_CONNECTION_INTERFACE_ADDRESSING;
-    } else if (feature == Contact::FeatureClientTypes) {
-        return TP_QT_IFACE_CONNECTION_INTERFACE_CLIENT_TYPES;
+        return TP_QT_FUTURE_IFACE_CONNECTION_INTERFACE_ADDRESSING;
     } else {
         warning() << "ContactManager doesn't know which interface corresponds to feature"
             << feature;
@@ -1560,13 +1536,6 @@ void ContactManager::ensureTracking(const Feature &feature)
         connect(simplePresenceInterface,
                 SIGNAL(PresencesChanged(Tp::SimpleContactPresences)),
                 SLOT(onPresencesChanged(Tp::SimpleContactPresences)));
-    } else if (feature == Contact::FeatureClientTypes) {
-        Client::ConnectionInterfaceClientTypesInterface *clientTypesInterface =
-            conn->interface<Client::ConnectionInterfaceClientTypesInterface>();
-
-        connect(clientTypesInterface,
-                SIGNAL(ClientTypesUpdated(uint,QStringList)),
-                SLOT(onClientTypesUpdated(uint,QStringList)));
     } else if (feature == Contact::FeatureRosterGroups || feature == Contact::FeatureAddresses) {
         // nothing to do here, but we don't want to warn
         ;
