@@ -367,9 +367,8 @@ void TextChannel::Private::processMessageQueue()
             int i = 0;
             while (i < messages.size()) {
                 if (messages.at(i).pendingId() == e->removed) {
-                    ReceivedMessage removedMessage = messages.at(i);
+                    emit parent->pendingMessageRemoved(messages.at(i));
                     messages.removeAt(i);
-                    emit parent->pendingMessageRemoved(removedMessage);
                 } else {
                     i++;
                 }
@@ -999,7 +998,7 @@ PendingSendMessage *TextChannel::send(const QString &text,
  *
  * This method requires TextChannel::FeatureCore to be ready.
  *
- * \param parts The message parts.
+ * \param part The message parts.
  * \param flags Flags affecting how the message is sent.
  *              Note that the channel may ignore some or all flags, depending on
  *              deliveryReportingSupport(); the flags that were handled by the CM are provided in
